@@ -115,6 +115,12 @@ class ShellTest(utils.TestCase):
         self.assertThat(help_text,
                         matchers.MatchesRegex(required))
 
+    def test_help_command_with_no_action_choices(self):
+        required = 'usage: keystone user-update'
+        help_text = self.shell('help user-update')
+        self.assertThat(help_text,
+                        matchers.MatchesRegex(required))
+
     def test_auth_no_credentials(self):
         with testtools.ExpectedException(
                 exceptions.CommandError, 'Expecting'):
@@ -313,9 +319,9 @@ class ShellTest(utils.TestCase):
             shell('tenant-create')
             assert do_tenant_mock.called
             # FIXME(dtroyer): how do you test the decorators?
-            #shell('tenant-create --tenant-name wilma '
+            # shell('tenant-create --tenant-name wilma '
             #        '--description "fred\'s wife"')
-            #assert do_tenant_mock.called
+            # assert do_tenant_mock.called
 
     def test_do_tenant_list(self):
         do_tenant_mock = mock.MagicMock()
